@@ -269,7 +269,7 @@ function install_masakaridashboard {
     $HORIZON_DIR/openstack_dashboard/local/enabled
     ln -fs $MASAKARI_DASHBOARD_DIR/masakaridashboard/local/local_settings.d/_50_masakari.py \
     $HORIZON_DIR/openstack_dashboard/local/local_settings.d
-    ln -fs $MASAKARI_DASHBOARD_DIR/masakaridashboard/conf/masakari_policy.yaml \
+    ln -fs $MASAKARI_DASHBOARD_DIR/masakaridashboard/conf/masakari_policy.json \
     $HORIZON_DIR/openstack_dashboard/conf
 }
 
@@ -277,7 +277,7 @@ function install_masakaridashboard {
 function uninstall_masakaridashboard {
     sudo rm -f  $DEST/horizon/openstack_dashboard/local/enabled/_50_masakaridashboard.py
     sudo rm -f  $DEST/horizon/openstack_dashboard/local/local_settings.d/_50_masakari.py
-    sudo rm -f  $DEST/horizon/openstack_dashboard/conf/masakari_policy.yaml
+    sudo rm -f  $DEST/horizon/openstack_dashboard/conf/masakari_policy.json
     restart_apache_server
 }
 
